==> aria2_0.9.0.orig.tar.gz: aria2-0.9.0/src/UrlRequestInfo.h <==
/* <!-- copyright */
/*
 * aria2 - The high speed download utility
 *
 * Copyright (C) 2006 Tatsuhiro Tsujikawa
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 *
 * In addition, as a special exception, the copyright holders give
 * permission to link the code of portions of this program with the
 * OpenSSL library under certain conditions as described in each
 * individual source file, and distribute linked combinations
 * including the two.
 * You must obey the GNU General Public License in all respects
 * for all of the code used other than OpenSSL.  If you modify
 * file(s) with this exception, you may extend this exception to your
 * version of the file(s), but you are not obligated to do so.  If you
 * do not wish to do so, delete this exception statement from your
 * version.  If you delete this exception statement from all source
 * files in the program, then also delete it here.
 */
/* copyright --> */
#ifndef _D_URL_REQUEST_INFO_H_
#define _D_URL_REQUEST_INFO_H_

#include "RequestInfo.h"

class UrlRequestInfo : public RequestInfo {
private:
  Strings urls;
  int maxConnections;
  RequestInfo* createNextRequestInfo() const;
  void adjustRequestSize(Requests& requests,
			 Requests& reserved,
			 int maxConnections) const;
  void printUrls(const Strings& urls) const;
public:
  UrlRequestInfo(const Strings& urls, int maxConnections, Option* op):
    RequestInfo(op),
    urls(urls),
    maxConnections(maxConnections) {}

  virtual ~UrlRequestInfo() {}

  virtual RequestInfos execute();
};

#endif // _D_URL_REQUEST_INFO_H_

==> aria2_0.11.0.orig.tar.gz: aria2-0.11.0/src/UrlRequestInfo.h <==
/* <!-- copyright */
/*
 * aria2 - The high speed download utility
 *
 * Copyright (C) 2006 Tatsuhiro Tsujikawa
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 *
 * In addition, as a special exception, the copyright holders give
 * permission to link the code of portions of this program with the
 * OpenSSL library under certain conditions as described in each
 * individual source file, and distribute linked combinations
 * including the two.
 * You must obey the GNU General Public License in all respects
 * for all of the code used other than OpenSSL.  If you modify
 * file(s) with this exception, you may extend this exception to your
 * version of the file(s), but you are not obligated to do so.  If you
 * do not wish to do so, delete this exception statement from your
 * version.  If you delete this exception statement from all source
 * files in the program, then also delete it here.
 */
/* copyright --> */
#ifndef _D_URL_REQUEST_INFO_H_
#define _D_URL_REQUEST_INFO_H_

#include "RequestInfo.h"

class HeadResult {
public:
  string filename;
  int64_t totalLength;
public:
  HeadResult():totalLength(0) {}
};

std::ostream& operator<<(std::ostream& o, const HeadResult& hr);

typedef SharedHandle<HeadResult> HeadResultHandle;

class UrlRequestInfo : public RequestInfo {
private:
  Strings urls;
  int maxConnections;
  string _filename;
  int64_t _totalLength;
#ifdef ENABLE_MESSAGE_DIGEST
  MessageDigestContext::DigestAlgo digestAlgo;
  int32_t chunkChecksumLength;
  Strings chunkChecksums;
#endif // ENABLE_MESSAGE_DIGEST

  RequestInfo* createNextRequestInfo() const;
  void adjustRequestSize(Requests& requests,
			 Requests& reserved,
			 int maxConnections) const;
  void printUrls(const Strings& urls) const;
  HeadResultHandle getHeadResult();
public:
  UrlRequestInfo(const Strings& urls, int maxConnections, Option* op):
    RequestInfo(op),
    urls(urls),
    maxConnections(maxConnections),
    _totalLength(0)
#ifdef ENABLE_MESSAGE_DIGEST
    ,
    digestAlgo(DIGEST_ALGO_SHA1),
    chunkChecksumLength(0)
#endif // ENABLE_MESSAGE_DIGEST
    {}

  virtual ~UrlRequestInfo() {}

  virtual RequestInfos execute();

#ifdef ENABLE_MESSAGE_DIGEST
  void setDigestAlgo(const MessageDigestContext::DigestAlgo& algo) {
    this->digestAlgo = algo;
  }
#endif // ENABLE_MESSAGE_DIGEST

#ifdef ENABLE_MESSAGE_DIGEST
  void setChunkChecksumLength(int32_t chunkChecksumLength) {
    this->chunkChecksumLength = chunkChecksumLength;
  }
#endif // ENABLE_MESSAGE_DIGEST

#ifdef ENABLE_MESSAGE_DIGEST
  void setChunkChecksums(const Strings& chunkChecksums) {
    this->chunkChecksums = chunkChecksums;
  }
#endif // ENABLE_MESSAGE_DIGEST

  void setTotalLength(int64_t totalLength)
  {
    _totalLength = totalLength;
  }

  void setFilename(const string& filename)
  {
    _filename = filename;
  }
};

typedef SharedHandle<UrlRequestInfo> UrlRequestInfoHandle;
#endif // _D_URL_REQUEST_INFO_H_
